@@ -6,7 +6,7 @@ __all__ = ("Data",)
 
 
 class Data(BaseData):
-    def _parse_value(
+    def parse_value(
         self,
         value: Any,
         data: Any,
