@@ -4,6 +4,10 @@ prices_and_variants = """
             <h2 class="name" itemprop="name">EasyBook Pro 15</h2>
             <div id="price">Was 999.9</div>
             <div id="sale-price">499.9</div>
+            <p class="instock availability">
+                <i class="icon-ok"></i>
+                In stock (10 available)
+            </p>
             <div id="color-variants">
                 Colors:
                 <div class="color" stock="true">
@@ -77,6 +81,26 @@ features = """
             <li>style: <strong>elegant</strong> is this</li>
             <li>Date added: Fri, 12 Dec 2018 10:55</li>
         </ul>
+        <table class="table specs">
+            <tr>
+                <th>Product Type</th>
+                <td>Books</td>
+            </tr>
+            <tr>
+                <th>Price (excl. tax)</th>
+                <td>£51.77</td>
+            </tr>
+        </table>
+        <table class="table2 specs2">
+            <tr>
+                <th>Product Type</th>
+                <td>Papers</td>
+            </tr>
+            <tr>
+                <th>Price (dddd. tax)</th>
+                <td>£52</td>
+            </tr>
+        </table>
     </div>
 """
 
